import {  } from 'prosemirror-transform'
import { find as language_find } from './../codemirror/language.mjs'
import { get, count, seq, nil_QMARK_, reduce, str, partial } from 'squint-cljs/core.js'
import { InputRule, wrappingInputRule } from 'prosemirror-inputrules';
import { Selection, TextSelection } from 'prosemirror-state';
import { findWrapping } from 'prosemirror-transform';
import { schema } from './../schema.mjs';
var supported_marks = ({ "`": "monospace", "_": "em", "*": "strong", "~": "strikethrough" })
;
var mark_input_rule = function (offset, state, match, start, end) {
let mark121 = match[1];
let mark_name122 = get(supported_marks, mark121);
let marked_content123 = match[2];
let mark_instance124 = schema.mark(mark_name122);
let mark_type125 = get(mark_instance124, "type");
let marked_content_start126 = (start + offset);
return state["tr"].setMeta("input-rule", mark_name122).insertText(marked_content123, marked_content_start126, end).addMark(marked_content_start126, (marked_content_start126 + count(marked_content123)), mark_instance124).removeStoredMark(mark_type125);
}
;
var atx_heading_rule = function (state, match, start, end) {
let node_type127 = schema["nodes"]["heading"];
let $start128 = state["doc"].resolve(start);
let attrs129 = ({ "level": count(match[1]) });
let start_index130 = $start128.index(-1);
let start_index_after131 = $start128.indexAfter(-1);
let start_node132 = $start128.node(-1);
if (!start_node132.canReplaceWith(start_index130, start_index_after131, node_type127)) {
return null;} else {
return state["tr"].setMeta("input-rule", get(node_type127, "name")).delete(start, end).setBlockType(start, start, node_type127, attrs129);}
}
;
var exit_mark_input_handler = function (state, _match) {
let $cursor133 = state["selection"]["$cursor"];
let pos134 = $cursor133["pos"];
let temp__25021__auto__135 = seq((state["storedMarks"] || $cursor133.marks()));
if (nil_QMARK_(temp__25021__auto__135)) {
return null;} else {
let marks136 = temp__25021__auto__135;
return reduce(function (tr, mark) {
return tr.removeStoredMark(mark);
}, state["tr"].insertText(" ", (pos134 - 1), pos134), marks136);}
}
;
var code_input_rule = function (state, match, start, end) {
return state["tr"].setMeta("input-rule", "code").insertText("", start, end).setBlockType(start, start, schema["nodes"]["code"], (function () {
 let temp__25021__auto__137 = match[1];
if (nil_QMARK_(temp__25021__auto__137)) {
return null;} else {
let info138 = temp__25021__auto__137;
let temp__25021__auto__139 = get(language_find(info138), "name");
if (nil_QMARK_(temp__25021__auto__139)) {
return null;} else {
let lang140 = temp__25021__auto__139;
return ({ "language": lang140.toLowerCase() });}}
})());
}
;
var formula_input_rule = (function () {
 let f141 = function (var_args) {
let G__144145 = arguments["length"];
switch (G__144145) {case 4:
return f141.cljs$core$IFn$_invoke$arity$4((arguments[0]), (arguments[1]), (arguments[2]), (arguments[3]));
break;
case 5:
return f141.cljs$core$IFn$_invoke$arity$5((arguments[0]), (arguments[1]), (arguments[2]), (arguments[3]), (arguments[4]));
break;
default:
throw new Error(str("Invalid arity: ", alength(arguments)))}
};
f141["cljs$core$IFn$_invoke$arity$4"] = function (state, match, start, end) {
return formula_input_rule(({  }), state, match, start, end);
};
f141["cljs$core$IFn$_invoke$arity$5"] = function (p__147, state, match, start, end) {
let map__148149 = p__147;
let inline_QMARK_150 = get(map__148149, "inline?");
let offset151 = get(map__148149, "offset", 0);
let node_type152 = (function () {
 let nodes153 = state["schema"]["nodes"];
if (inline_QMARK_150) {
return nodes153["inline_formula"];} else {
return nodes153["formula"];}
})();
return state["tr"].setMeta("input-rule", "formula").setSelection(new Selection(state["doc"].resolve((start + offset151)), state["doc"].resolve(end))).replaceSelectionWith((inline_QMARK_150) ? (node_type152.createAndFill(({  }), schema.text(get(match, 1)))) : (node_type152.createAndFill()));
};
f141["cljs$lang$maxFixedArity"] = 5;
return f141;
})()
;
var wrapping_input_handler = function (node_type, state, match, start, end) {
let tr154 = state["tr"].delete(start, end);
console.log("R", tr154["doc"].resolve(start).blockRange());
let temp__25021__auto__155 = tr154["doc"].resolve(start).blockRange();
if (nil_QMARK_(temp__25021__auto__155)) {
return null;} else {
let range156 = temp__25021__auto__155;
let temp__25021__auto__157 = findWrapping(range156, node_type);
if (nil_QMARK_(temp__25021__auto__157)) {
return null;} else {
let wrapping158 = temp__25021__auto__157;
return tr154.wrap(range156, wrapping158);}}
}
;
var input_rules = [new InputRule(/^(#{1,4})\s$/, atx_heading_rule), wrappingInputRule(/^\s*([-+*])\s$/, schema["nodes"]["bullet_list"]), wrappingInputRule(/^\s*(1[\)\.])\s$/, schema["nodes"]["numbered_list"]), wrappingInputRule(/^\s*([-+*]\[[x ]*\])\s$/, schema["nodes"]["todo_list"]), wrappingInputRule(/^\s*(>+)\s$/, schema["nodes"]["blockquote"]), new InputRule(/^(\$\$)\s$/, formula_input_rule), new InputRule(/^\$([^\$]*[^ ])\$$/, partial(formula_input_rule, ({ "inline?": true }))), new InputRule(/\s\$([^\$]*[^ ])\$$/, partial(formula_input_rule, ({ "inline?": true, "offset": 1 }))), new InputRule(/^```([a-zA-Z]*)\s$/, code_input_rule), new InputRule(/\s([*_~`])([^`]+)\1$/, partial(mark_input_rule, 1)), new InputRule(/^([*_~`])([^`]+)\1$/, partial(mark_input_rule, 0)), new InputRule(/\s\s$/, exit_mark_input_handler)]
;

export { supported_marks, mark_input_rule, atx_heading_rule, exit_mark_input_handler, code_input_rule, formula_input_rule, wrapping_input_handler, input_rules }
